import dayjs from 'dayjs';
import { z } from 'zod';
import PeopleAltIcon from '@mui/icons-material/PeopleAlt';
import { DateFormat, EditApiMethod, FieldEnum, ROUTES, TableCellType } from '../../constants';
import { PaginationMethod } from '../../types/common-types';
var RewardField;
(function (RewardField) {
    RewardField["RewardUrl"] = "reward_url";
    RewardField["Rewards"] = "rewards";
    RewardField["DATE"] = "date";
    RewardField["Status"] = "is_active";
    RewardField["PointsRequired"] = "point_required";
})(RewardField || (RewardField = {}));
const RewardSchema = z.object({
    [RewardField.RewardUrl]: z.any().optional(),
    [RewardField.Rewards]: z.array(z.any()).optional(),
    [RewardField.DATE]: z.optional(z.string()).optional(),
    [RewardField.Status]: z.boolean().optional(),
    [RewardField.PointsRequired]: z.number().optional(),
});
export const DATA = {
    title: 'Rewards',
    tables: [
        {
            key: 'rewards',
            detailsRoute: ROUTES.DEMO_DETAILS,
            editApiMethod: EditApiMethod.PUT,
            apiEndPoint: {
                ALL: 'https://il2ssyeeu5.execute-api.ap-south-1.amazonaws.com/dev/v2/milestone-rewards',
            },
            handleDetailsSubmit: async (data) => {
                return data;
            },
            columns: [
                {
                    field: RewardField.RewardUrl,
                    headerName: "Reward's URL",
                    sortable: true,
                    filterProps: {
                        fieldType: FieldEnum.Text,
                    },
                },
                {
                    field: RewardField.PointsRequired,
                    headerName: 'Points Required',
                    filterProps: {
                        fieldType: FieldEnum.Number,
                    },
                },
                {
                    field: RewardField.Rewards,
                    headerName: 'Rewards',
                    renderCellProps: {
                        type: TableCellType.DATE_TIME,
                    },
                    fieldProps: {
                        fieldType: FieldEnum.DateTime,
                        dateFormat: DateFormat.ISO8601,
                        minDate: dayjs(),
                    },
                },
            ],
            enableExport: true,
            actions: {
                edit: true,
                delete: true,
                view: true,
                add: true,
                filter: true,
                search: false,
                toggle: true,
            },
            customActions: [
                {
                    label: 'Activate',
                    key: 'activate',
                    handleClick: (row) => {
                        console.log('Activate', row);
                    },
                    showInMenu: false,
                    Icon: PeopleAltIcon,
                },
            ],
            pagination: true,
            paginationMethod: PaginationMethod.OFFSET,
            schema: RewardSchema,
            defaultValues: {
                [RewardField.RewardUrl]: '',
            },
        },
    ],
};
